pub struct DefaultExecutor<K: Kernel> { /* private fields */ }
The default Executor.

Warning

Message execution might run out of stack and crash (the entire process) if it doesn’t have at least 64MiB of stack space. If you can’t guarantee 64MiB of stack space, wrap this executor in a ThreadedExecutor.

Implementations

source

impl<K> DefaultExecutor<K>where K: Kernel,

source

pub fn new( engine_pool: EnginePool, machine: <K::CallManager as CallManager>::Machine ) -> Result<Self>

Create a new DefaultExecutor for executing messages on the Machine.

source

pub fn into_machine(self) -> Option<<K::CallManager as CallManager>::Machine>

Consume consumes the executor and returns the Machine. If the Machine had been poisoned during execution, the Option will be None.