Struct fvm::kernel::SyscallError
source · pub struct SyscallError(pub String, pub ErrorNumber);Expand description
Represents an error from a syscall. It can optionally contain a syscall-advised exit code for the kind of error that was raised. We may want to add an optional source error here.
Automatic conversions from String are provided, with no advised exit code.
Tuple Fields
0: String1: ErrorNumberImplementations
sourceimpl SyscallError
impl SyscallError
pub fn new<D: Display>(c: ErrorNumber, d: D) -> Self