pub struct Engine(_);
A caching wasmtime engine.

Implementations

Create a new Engine from a wasmtime config.

Instantiates and caches the Wasm modules for the bytecodes addressed by the supplied CIDs. Only uncached entries are actually fetched and instantiated. Blockstore failures and entry inexistence shortcircuit make this method return an Err immediately.

Load some wasm code into the engine.

Load compiled wasm code into the engine.

Safety

See wasmtime::Module::deserialize for safety information.

Lookup a loaded wasmtime module.

Lookup and instantiate a loaded wasmtime module with the given store. This will cache the linker, syscalls, “pre” isntance, etc.

Construct a new wasmtime “store” from the given kernel.

Methods from Deref<Target = Engine>

Returns the configuration settings that this engine is using.

Increments the epoch.

When using epoch-based interruption, currently-executing Wasm code within this engine will trap or yield “soon” when the epoch deadline is reached or exceeded. (The configuration, and the deadline, are set on the Store.) The intent of the design is for this method to be called by the embedder at some regular cadence, for example by a thread that wakes up at some interval, or by a signal handler.

See Config::epoch_interruption for an introduction to epoch-based interruption and pointers to the other relevant methods.

Signal Safety

This method is signal-safe: it does not make any syscalls, and performs only an atomic increment to the epoch value in memory.

Ahead-of-time (AOT) compiles a WebAssembly module.

The bytes provided must be in one of two formats:

  • A binary-encoded WebAssembly module. This is always supported.
  • A text-encoded instance of the WebAssembly text format. This is only supported when the wat feature of this crate is enabled. If this is supplied then the text format will be parsed before validation. Note that the wat feature is enabled by default.

This method may be used to compile a module for use with a different target host. The output of this method may be used with Module::deserialize on hosts compatible with the Config associated with this Engine.

The output of this method is safe to send to another host machine for later execution. As the output is already a compiled module, translation and code generation will be skipped and this will improve the performance of constructing a Module from the output of this method.