Module executor
fvm
4.8.2
Module executor
Module Items
Structs
Enums
Traits
In crate fvm
fvm
Module
executor
Structs

Apply
Ret
Apply message return data.
Default
Executor
The default
Executor
.
Threaded
Executor
An executor that executes messages on a separate thread with a 64MiB stack. If you can guarantee at least 64MiB of stack space, you don’t need this executor.
Enums

Apply
Failure
A description of some failure encountered when applying a message.
Apply
Kind
The kind of message being applied:
Traits

Executor
An executor executes messages on the underlying machine/kernel. It’s responsible for: