pub trait GasOps {
fn charge_gas(&mut self, name: &str, compute: i64) -> Result<()>;
}Expand description
Operations for explicit gas charging.
TODO this is unsafe; most gas charges should occur as part of syscalls, but some built-in actors currently charge gas explicitly for concrete actions. In the future (Phase 1), this should disappear and be replaced by gas instrumentation at the WASM level.