pub struct Engine(_);Expand description
A caching wasmtime engine.
Implementations
sourceimpl Engine
impl Engine
sourcepub fn preload<'a, BS, I>(&self, blockstore: BS, cids: I) -> Result<()> where
BS: Blockstore,
I: IntoIterator<Item = &'a Cid>,
pub fn preload<'a, BS, I>(&self, blockstore: BS, cids: I) -> Result<()> where
BS: Blockstore,
I: IntoIterator<Item = &'a Cid>,
Instantiates and caches the Wasm modules for the bytecodes addressed by the supplied CIDs. Only uncached entries are actually fetched and instantiated. Blockstore failures and entry inexistence shortcircuit make this method return an Err immediately.
sourcepub fn load_bytecode(&self, k: &Cid, wasm: &[u8]) -> Result<Module>
pub fn load_bytecode(&self, k: &Cid, wasm: &[u8]) -> Result<Module>
Load some wasm code into the engine.
sourcepub unsafe fn load_compiled(&self, k: &Cid, compiled: &[u8]) -> Result<Module>
pub unsafe fn load_compiled(&self, k: &Cid, compiled: &[u8]) -> Result<Module>
Load compiled wasm code into the engine.
Safety
See wasmtime::Module::deserialize for safety information.
sourcepub fn get_module(&self, k: &Cid) -> Option<Module>
pub fn get_module(&self, k: &Cid) -> Option<Module>
Lookup a loaded wasmtime module.
sourcepub fn get_instance<K: Kernel>(
&self,
store: &mut Store<InvocationData<K>>,
k: &Cid
) -> Result<Option<Instance>>
pub fn get_instance<K: Kernel>(
&self,
store: &mut Store<InvocationData<K>>,
k: &Cid
) -> Result<Option<Instance>>
Lookup and instantiate a loaded wasmtime module with the given store. This will cache the linker, syscalls, “pre” isntance, etc.
sourcepub fn new_store<K: Kernel>(&self, kernel: K) -> Store<InvocationData<K>>
pub fn new_store<K: Kernel>(&self, kernel: K) -> Store<InvocationData<K>>
Construct a new wasmtime “store” from the given kernel.
Methods from Deref<Target = Engine>
sourcepub fn increment_epoch(&self)
pub fn increment_epoch(&self)
Increments the epoch.
When using epoch-based interruption, currently-executing Wasm
code within this engine will trap or yield “soon” when the
epoch deadline is reached or exceeded. (The configuration, and
the deadline, are set on the Store.) The intent of the
design is for this method to be called by the embedder at some
regular cadence, for example by a thread that wakes up at some
interval, or by a signal handler.
See Config::epoch_interruption
for an introduction to epoch-based interruption and pointers
to the other relevant methods.
Signal Safety
This method is signal-safe: it does not make any syscalls, and performs only an atomic increment to the epoch value in memory.
sourcepub fn precompile_module(&self, bytes: &[u8]) -> Result<Vec<u8, Global>, Error>
pub fn precompile_module(&self, bytes: &[u8]) -> Result<Vec<u8, Global>, Error>
Ahead-of-time (AOT) compiles a WebAssembly module.
The bytes provided must be in one of two formats:
- A binary-encoded WebAssembly module. This is always supported.
- A text-encoded instance of the WebAssembly text format.
This is only supported when the
watfeature of this crate is enabled. If this is supplied then the text format will be parsed before validation. Note that thewatfeature is enabled by default.
This method may be used to compile a module for use with a different target
host. The output of this method may be used with
Module::deserialize on hosts compatible
with the Config associated with this Engine.
The output of this method is safe to send to another host machine for later
execution. As the output is already a compiled module, translation and code
generation will be skipped and this will improve the performance of constructing
a Module from the output of this method.